==> OpenPatricianEngine-0.9.1-sources.jar: ch/sahits/game/openpatrician/engine/player/tradesteps/TransferToOfficeTradeStep.java <==
package ch.sahits.game.openpatrician.engine.player.tradesteps;

import ch.sahits.game.openpatrician.clientserverinterface.service.TradeService;
import ch.sahits.game.openpatrician.model.IAIPlayer;
import ch.sahits.game.openpatrician.model.building.ITradingOffice;
import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.product.ITradeStep;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.ship.INavigableVessel;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.Prototype;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import static java.util.stream.Collectors.toList;

/**
 * Trade step for transferring all wares to the store if it can be stored and there is a store manager, to sell them.
 * @author Andi Hotz, (c) Sahits GmbH, 2017
 * Created on Oct 20, 2017
 */
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
@Prototype
public class TransferToOfficeTradeStep implements ITradeStep {
    @Setter
    private ICity city;

    @Setter
    private INavigableVessel vessel;
    @Autowired
    @XStreamOmitField
    private TradeService tradeService;

    @Override
    public boolean execute() {
        IAIPlayer player = (IAIPlayer) vessel.getOwner();
        Optional<ITradingOffice> optOffice = player.findTradingOffice(city);
        //noinspection OptionalIsPresent
        if (optOffice.isPresent()) {
            ITradingOffice office = optOffice.get();
            if (office.getSteward().isPresent()) {
                List<IWare> neededWares = tradeService.getBasicNeeds();
                List<IWare> transferableWares = vessel.getLoadedWares().stream()
                        .filter(neededWares::contains)
                        .collect(toList());
                Map<IWare, Integer> map = new HashMap<>();
                for (IWare ware : transferableWares) {
                    int amount = vessel.getWare(ware).getAmount();
                    if (ware.isBarrelSizedWare()) {
                        amount *= 10;
                    }
                    int availableSpace = office.capacityProperty().get();
                    int movableAmount = Math.min(availableSpace, amount);
                    map.put(ware, movableAmount);
                }
                if (!map.isEmpty()) {
                    tradeService.transferFromVesselToStorage(vessel, player, city, map);
                }
            }
        }
        return true;
    }
}

==> OpenPatricianEngine-1.0.1-sources.jar: ch/sahits/game/openpatrician/engine/player/tradesteps/TransferToOfficeTradeStep.java <==
package ch.sahits.game.openpatrician.engine.player.tradesteps;

import ch.sahits.game.openpatrician.clientserverinterface.service.TradeService;
import ch.sahits.game.openpatrician.model.IAIPlayer;
import ch.sahits.game.openpatrician.model.IPlayer;
import ch.sahits.game.openpatrician.model.building.ITradingOffice;
import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.product.ITradeStep;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.ship.INavigableVessel;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.Prototype;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import static java.util.stream.Collectors.toList;

/**
 * Trade step for transferring all wares to the store if it can be stored and there is a store manager, to sell them.
 * @author Andi Hotz, (c) Sahits GmbH, 2017
 * Created on Oct 20, 2017
 */
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
@Prototype
public class TransferToOfficeTradeStep implements ITradeStep {
    @Setter
    private ICity city;

    @Setter
    private INavigableVessel vessel;
    @Autowired
    @XStreamOmitField
    private TradeService tradeService;

    @Override
    public boolean execute() {
        IAIPlayer player = (IAIPlayer) vessel.getOwner();
        Optional<ITradingOffice> optOffice = player.findTradingOffice(city);
        //noinspection OptionalIsPresent
        if (optOffice.isPresent()) {
            ITradingOffice office = optOffice.get();
            if (office.getSteward().isPresent()) {
                List<IWare> neededWares = tradeService.getBasicNeeds();
                List<IWare> transferableWares = vessel.getLoadedWares().stream()
                        .filter(neededWares::contains)
                        .collect(toList());
                Map<IWare, Integer> map = new HashMap<>();
                for (IWare ware : transferableWares) {
                    int amount = vessel.getWare(ware).getAmount();
                    if (ware.isBarrelSizedWare()) {
                        amount *= 10;
                    }
                    int availableSpace = office.capacityProperty().get();
                    int movableAmount = Math.min(availableSpace, amount);
                    map.put(ware, movableAmount);
                }
                if (!map.isEmpty()) {
                    tradeService.transferFromVesselToStorage(vessel, player, city, map);
                }
            }
        }
        return true;
    }

    @Override
    public String toString() {
        List<IWare> neededWares = tradeService.getBasicNeeds();
        StringBuilder sb = new StringBuilder();
        vessel.getLoadedWares().stream().filter(neededWares::contains).forEach(ware -> sb.append(ware).append(", "));
        String wares = sb.toString();
        wares = wares.substring(0, wares.lastIndexOf(","));
        return "TransferToOfficeTradeStep "+ ((IPlayer)vessel.getOwner()).getUuid() +"{Transfer "
                + wares + " from "
                + vessel.getName() + "("
                + vessel.getUuid() + ") in "
                + city.getName() + "}";
    }
}
